<?php

declare(strict_types=1);

namespace Drupal\style_options_spacing\Plugin\StyleOption;

use Drupal\Core\Form\FormStateInterface;
use Drupal\style_options\StyleOptionStyleTrait;
use Drupal\style_options\Plugin\StyleOptionPluginBase;


abstract class StyleOptionSpacingPresetBase extends StyleOptionPluginBase {

  use StyleOptionStyleTrait;

  private function getPresetSpacingOptions() : array {
    // This assumes the options that are usually available with Tailwind.
    $default = [
      '1' => 1,
      '2' => 2,
      '3' => 3,
      '4' => 4,
      '5' => 5,
      '6' => 6,
      '7' => 7,
      '8' => 8,
    ];

    // @todo: Add hook call to alter these values.
    return $default;
  }

  protected function getPresetSpacingOptionsFieldForm(array $defaultValues) : array {
    $spacingOptions = $this->getPresetSpacingOptions();
    return [
      'vertical' => [
        '#description' => $this->t('A spacing preset.'),
        '#description_display' => 'before',
        '#type' => 'fieldset',
        '#title' => $this->t('Vertical'),
        'top' => [
          '#empty_option' => $this->t('None'),
          '#default_value' => $defaultValues['vertical']['top'] ?? NULL,
          '#options' => $spacingOptions,
          '#type' => 'select',
          '#title' => $this->t('Top'),
        ],
        'bottom' => [
          '#empty_option' => $this->t('None'),
          '#default_value' => $defaultValues['vertical']['bottom'] ?? NULL,
          '#options' => $spacingOptions,
          '#type' => 'select',
          '#title' => $this->t('Bottom'),
        ],
      ],
      'horizontal' => [
        '#description' => $this->t('A spacing preset.'),
        '#description_display' => 'before',
        '#type' => 'fieldset',
        '#title' => $this->t('Horizontal'),
        'left' => [
          '#default_value' => $defaultValues['horizontal']['left'] ?? NULL,
          '#empty_option' => $this->t('None'),
          '#options' => $spacingOptions,
          '#type' => 'select',
          '#title' => $this->t('Left'),
        ],
        'right' => [
          '#default_value' => $defaultValues['horizontal']['right'] ?? NULL,
          '#empty_option' => $this->t('None'),
          '#options' => $spacingOptions,
          '#type' => 'select',
          '#title' => $this->t('Right'),
        ],
      ],
    ];
  }

  protected function getFreeSpacingFieldForm(array $defaultValues) : array {
    return [
      'vertical' => [
        '#description' => $this->t('Enter values with the unit, e.g. 10px, 30rem, etc.'),
        '#description_display' => 'before',
        '#type' => 'fieldset',
        '#title' => $this->t('Vertical'),
        'top' => [
          '#default_value' => $defaultValues['vertical']['top'] ?? NULL,
          '#type' => 'textfield',
          '#title' => $this->t('Top'),
        ],
        'bottom' => [
          '#default_value' => $defaultValues['vertical']['bottom'] ?? NULL,
          '#type' => 'textfield',
          '#title' => $this->t('Bottom'),
        ],
      ],
      'horizontal' => [
        '#description' => $this->t('Enter values with the unit, e.g. 10px, 30rem, etc.'),
        '#description_display' => 'before',
        '#type' => 'fieldset',
        '#title' => $this->t('Horizontal'),
        'left' => [
          '#default_value' => $defaultValues['horizontal']['left'] ?? NULL,
          '#type' => 'textfield',
          '#title' => $this->t('Left'),
        ],
        'right' => [
          '#default_value' => $defaultValues['horizontal']['right'] ?? NULL,
          '#type' => 'textfield',
          '#title' => $this->t('Right'),
        ],
      ],
    ];
  }
}
